# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import fields, osv
from tools.translate import _
from crm import crm
import time
import zipfile
import cStringIO
import base64


class crm_postmail(crm.crm_case, osv.osv):
    """ MailPost Cases """

    _name = "crm.postmail"
    _description = "Postmail"
    _order = "id desc"


    def _get_address(self, cr, uid, address_id, context = None):
        address = self.pool.get('res.partner.address').browse(cr, uid, address_id)
        return """%(title)s %(name)s
%(street)s%(street2)s%(zip)s %(city)s
%(state)s%(country)s""" % { 'title': address.title or '',
                'name': address.name or address.partner_id.name or _('Without name'),
                'street': address.street and address.street+'\n' or '',
                'street2': address.street2 and address.street2+'\n' or '',
                'zip': address.zip or '',
                'city': address.city or '',
                'state': address.state_id and address.state_id.name+'\n' or '',
                'country': address.country_id and address.country_id.name+'\n' or '',}

    def _generate_address(self, cr, uid, ids, field_name, arg, context = None):
        ret = {}
        for item in self.browse(cr, uid, ids, context = context):
            ret[item.id] = item.partner_address_id and self._get_address(cr, uid, item.partner_address_id.id, context = context) or ''
        return ret

    _columns = {
        # From crm.case
        'id': fields.integer('ID'),
        'name': fields.char('Post Summary', size=64),
        'active': fields.boolean('Active', required=False), 
        'date_action_last': fields.datetime('Last Action', readonly=1),
        'date_action_next': fields.datetime('Next Action', readonly=1), 
        'create_date': fields.datetime('Creation Date' , readonly=True),
        'section_id': fields.many2one('crm.case.section', 'Sales Team', \
                        select=True, help='Sales team to which Case belongs to.'), 
        'user_id': fields.many2one('res.users', 'Responsible'), 
        'partner_id': fields.many2one('res.partner', 'Partner'), 
        'partner_address_id': fields.many2one('res.partner.address', 'Partner Contact', \
                                 domain="[('partner_id','=',partner_id)]"), 
        'company_id': fields.many2one('res.company', 'Company'), 
        'description': fields.text('Description'), 
        'state': fields.selection([
                                    ('draft', 'Draft'), 
                                    ('open', 'Todo'), 
                                    ('cancel', 'Cancelled'), 
                                    ('done', 'Done'), 
                                    ('pending', 'Pending'),
                                ], 'State', size=16, readonly=True, 
                                  help='The state is set to \'Draft\', when a case is created.\
                                  \nIf the case is in progress the state is set to \'Open\'.\
                                  \nWhen the case is over, the state is set to \'Done\'.\
                                  \nIf the case needs to be reviewed then the state is set to \'Pending\'.'), 
        'email_from': fields.char('Email', size=128, help="These people will receive email."), 
        'date_open': fields.datetime('Opened', readonly=True),
        
        # postmail fields
        'categ_id': fields.many2one('crm.case.categ', 'Category', \
                        domain="['|',('section_id','=',section_id),('section_id','=',False),\
                        ('object_id.model', '=', 'crm.postmail')]"),
        'partner_address': fields.text('Mail to send',),
        'priority': fields.selection(crm.AVAILABLE_PRIORITIES, 'Priority'), 
        'date': fields.datetime('Date'), 
        'message_ids': fields.one2many('mailgate.message', 'res_id', 'Messages', domain=[('model','=',_name)]),
        'document' : fields.many2one('ir.attachment',string='Document',),
    }

    _defaults = {
        'date': lambda *a: time.strftime('%Y-%m-%d %H:%M:%S'), 
        'priority': lambda *a: crm.AVAILABLE_PRIORITIES[2][0], 
        'state': lambda *a: 'open', 
        'user_id': lambda self,cr,uid,ctx: uid,
        'active': lambda *a: 1, 
    }
    
    # From crm.case

    def onchange_partner_address_id(self, cr, uid, ids, add, email=False):
        res = super(crm_postmail, self).onchange_partner_address_id(cr, uid, ids, add, email)
        res.setdefault('value', {})
        if add:
            res['value']['partner_address'] = self._get_address(cr, uid, add)
        return res

    def message_append(self, cr, uid, cases, message_text):
        return True

crm_postmail()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
